//
//  EMBEmberApplicationInterface.h
//  Ember
//
//  Created by Damien DeVille on 05/07/2012.
//  Copyright (c) 2012 Realmac Software. All rights reserved.
//

#import <Foundation/Foundation.h>

@class EMBPersistentStoreNotification, EMBEmberLibrary;

@protocol EMBBaseRemoteInterface <NSObject>

- (void)checkin;

/*!
	\brief
	Invoked and received when a save in the persistent store in an application has been triggered.
 */
- (void)persistentStoreUpdated:(EMBPersistentStoreNotification *)storeNotification;

/*!
	\brief
	Import the assets at the given locations. `assetLocations` is an array of bookmark data objects
	for the asset URLs.
 */
- (void)importAssetsAtLocations:(NSArray *)assetLocations completion:(void (^)(BOOL success, NSError *error))completion;

/*!
	\brief
	Import the image. `imageData` is data for an `NSImage` object.
 */
- (void)importImage:(NSData *)image fileType:(NSString *)fileType filename:(NSString *)filename completion:(void (^)(BOOL success, NSError *error))completion;

/*!
	\brief
	Perform screen snapping. `snapType` is a boxed `RMScreenSnapType`.
 */
- (void)screenSnap:(NSNumber *)snapType;

@end

@protocol EMBEmberRemoteInterface <EMBBaseRemoteInterface>

@end

@protocol EMBEmberLibraryMediatorRemoteInterface <EMBBaseRemoteInterface>

/*!
	\brief
	Can be used by a client application to have the library mediator to mount a particular library specified by the identifier.
 */
- (void)attemptMountingLibraryWithIdentifier:(NSURL *)libraryIdentifier;

/*!
	\brief
	Deleech the Ensembles for the library that is currently mounted.
 */
- (void)deleechEnsemblesForCurrentLibrary:(void (^)(NSError *error))completion;

/*!
	\brief
	Check whether the application is running critical ongoing activities.
 */
- (void)checkCriticalOnGoingActivities:(void (^)(BOOL hasCriticalOnGoingActivities))completion;

/*!
	\brief
	Retrieve a security scoped bookmark data (scoped to the library mediator application) for the given bookmark data.
 */
- (void)retrieveSecurityScopedBookmarkData:(NSData *)bookmarkData completion:(void (^)(NSData *securityScopedBookmarkData, NSError *error))completion;

/*!
	\brief
	Retrieve and store a security scoped bookmark data for the given bookmark data.
 */
- (void)retrieveSecurityScopedBookmarkData:(NSData *)bookmarkData storeToDefault:(NSString *)defaultKey completion:(void (^)(BOOL success, NSError *error))completion;

@end

@protocol EMBEmberStatusItemRemoteInterface <NSObject>

@end

@interface NSXPCInterface (EMBEmberApplicationInterface)

- (void)setupClassesForMethodArguments;

@end
