//
//  EMBEmberLibrary.h
//  Ember
//
//  Created by Damien DeVille on 17/05/2012.
//  Copyright (c) 2012 Realmac Software. All rights reserved.
//

#import <Foundation/Foundation.h>

#import "EMBEmberData/EMBEmberFileManager.h"

@class NSPersistentStore;
@class EMBEmberJournal;

@interface EMBEmberLibrary : NSObject

/*!
	\brief
	Library identifier.
 */
@property (readonly, copy, nonatomic) NSURL *libraryIdentifier;
extern NSString * const EMBEmberLibraryIdentifierKey;

/*!
	\brief
	Library contents location.
 */
@property (readonly, copy, nonatomic) NSURL *libraryContentsLocation;
extern NSString * const EMBEmberLibraryContentsLocationKey;

/*!
	\brief
	Directory where the snap documents are stored.
 */
@property (readonly, copy, nonatomic) NSURL *snapsDirectoryLocation;
extern NSString * const EMBEmberLibrarySnapsDirectoryLocationKey;

/*!
	\brief
	Directory where the snap thumbnails are stored.
 */
@property (readonly, copy, nonatomic) NSURL *thumbnailsDirectoryLocation;
extern NSString * const EMBEmberLibraryThumbnailsDirectoryLocationKey;

/*!
	\brief
	Directory where the upload presets are stored.
 */
@property (readonly, copy, nonatomic) NSURL *uploadPresetsDirectoryLocation;
extern NSString * const EMBEmberLibraryUploadPresetsDirectoryLocationKey;

/*!
	\brief
	Persistent store location.
 */
@property (readonly, strong, nonatomic) NSPersistentStore *persistentStore;
extern NSString * const EMBEmberLibraryPersistentStoreKey;

/*!
	\brief
	YES if the library has Ensembles.
 */
@property (readonly, assign, nonatomic) BOOL hasEnsembles;
extern NSString * const EMBEmberLibraryHasEnsemblesKey;

/*!
	\brief
	Nil until the Ember Library has been mounted.
 */
@property (readonly, strong, nonatomic) EMBEmberJournal *journal;

/*!
	\brief
	A file manager that can be used to do file operations inside the library.
 */
@property (readonly, strong, nonatomic) id <EMBEmberFileManager> fileManager;

@end

extern NSString * const EMBEmberLibrarySnapsDirectoryName;
extern NSString * const EMBEmberLibraryThumbnailsDirectoryName;
extern NSString * const EMBEmberLibraryUploadPresetsDirectoryName;
