//
//  EMBEmberNaturalLanguageColors.h
//  EmberCommon
//
//  Created by Damien DeVille on 10/2/13.
//  Copyright (c) 2013 Realmac Software. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface EMBEmberColor : NSObject

@property (readonly, copy, nonatomic) NSString *key;
@property (readonly, copy, nonatomic) NSString *localisedName;
@property (readonly, assign, nonatomic) NSUInteger hexValue;

@end

/*!
	\brief
	An array of all EMBEmberColor objects.
 */
extern NSArray *EMBEmberColorGetAllColors(void);

/*!
	\brief
	An array of EMBEmberColor objects that can be selected in the interface.
 */
extern NSArray *EMBEmberColorGetSelectableColors(void);

/*!
	\brief
	Find the EMBEmberColor for a given color key.
 */
extern EMBEmberColor *EMBEmberColorForKey(NSString *key);

/*!
	\brief
	Find the color hex value for a given input string.
	It will perform a search against the EMBEmberColor array and attempt to the string as an Hex value color if it starts with #.
 */
extern NSNumber *EMBEmberColorFindHexColorForInputString(NSString *inputString);

typedef NS_ENUM(NSInteger, EMBEmberColorSearchTolerance) {
	EMBEmberColorSearchToleranceNarrow = 0,
	EMBEmberColorSearchToleranceBest = 1,
	EMBEmberColorSearchToleranceBroad = 2,
};

/*!
	\brief
	Returns a predicate suitable for searching a colour.
 */
extern NSPredicate *EMBEmberColorSearchPredicate(NSUInteger hexColorValue, EMBEmberColorSearchTolerance tolerance, NSString *redComponentKey, NSString *greenComponentKey, NSString *blueComponentKey, NSString *sortColorKey);

/*!
	\brief
	Create a native color from a hex color value.
 */
extern id EMBEmberColorCreateNativeColorFromHexValue(NSUInteger hexColorValue);
