//
// Copyright (C) 2008-2011 Realmac Software Ltd
//
// These coded instructions, statements, and computer programs contain
// unpublished proprietary information of Realmac Software Ltd
// and are protected by copyright law. They may not be disclosed
// to third parties or copied or duplicated in any form, in whole or
// in part, without the prior written consent of Realmac Software Ltd.
//

#import <CoreData/CoreData.h>

#import "EMBEmberHelpers/EMBEmberHelpers.h"

#import "EMBPersistentStoreCopying.h"

extern NSString * const EMBSnapEntityName;

extern NSUInteger const EMBSnapCommentsMaxLength;

@class EMBImport, EMBCollection, EMBTag, EMBPortableColor, EMBSnapDocument;

typedef NS_ENUM(NSInteger, EMBSnapType) {
	EMBSnapTypeUnknown = 0,
	EMBSnapTypeScreenshot = 1,
	EMBSnapTypeWebsnap = 2,
	EMBSnapTypePhoto = 3,
	EMBSnapTypeTablet = 4,
	EMBSnapTypePhone = 5,
	EMBSnapTypeOther = 6,
	EMBSnapTypeText = 7,
	EMBSnapTypeVideo = 8,
	EMBSnapTypeBookmark = 9,
};

@interface EMBSnap : NSManagedObject <EMBPersistentStoreCopying>

// Creating new objects
+ (EMBSnap *)createSnapInManagedObjectContext:(NSManagedObjectContext *)context persistentStore:(NSPersistentStore *)persistentStore title:(NSString *)title type:(EMBSnapType)type;
+ (EMBSnap *)findSnapMatchingSnapDocument:(EMBSnapDocument *)snapDocument managedObjectContext:(NSManagedObjectContext *)context persistentStore:(NSPersistentStore *)persistentStore;
+ (EMBSnap *)createSnapWithSnapDocument:(EMBSnapDocument *)snapDocument managedObjectContext:(NSManagedObjectContext *)context persistentStore:(NSPersistentStore *)persistentStore;

#if TARGET_OS_IPHONE
+ (NSFetchedResultsController *)fetchedResultsControllerInManagedObjectContext:(NSManagedObjectContext *)managedObjectContext sortingAscending:(BOOL)ascending;
#endif /* TARGET_OS_IPHONE */

extern NSString * const EMBSnapUUIDKey;
@property (copy, nonatomic) NSString *uuid;

extern NSString * const EMBSnapTitleKey;
@property (copy, nonatomic) NSString *title;

extern NSString * const EMBSnapRatingKey;
@property (assign, nonatomic) NSInteger rating;
- (BOOL)validateRating:(NSNumber **)ratingRef error:(NSError **)errorRef;

extern NSString * const EMBSnapTypeKey;
@property (assign, nonatomic) EMBSnapType type;

extern NSString * const EMBSnapCommentsKey;
@property (copy, nonatomic) NSString *comments;

extern NSString * const EMBSnapDateKey;
@property (strong, nonatomic) NSDate *date;

extern NSString * const EMBSnapURLKey;
@property (copy, nonatomic) NSURL *url;

extern NSString * const EMBSnapURLStringKey;
@property (copy, nonatomic) NSString *urlString;

extern NSString * const EMBSnapCollectionsKey;
@property (strong, nonatomic) NSSet *collections;

extern NSString * const EMBSnapSharingDestinationsKey;
@property (strong, nonatomic) NSSet *sharingDestinations;

extern NSString * const EMBSnapTagsKey;
@property (strong, nonatomic) NSSet *tags;

extern NSString * const EMBSnapHasAnnotationsKey;
@property (assign, nonatomic) BOOL hasAnnotations;

extern NSString * const EMBSnapHasWebArchiveKey;
@property (assign, nonatomic) BOOL hasWebArchive;

extern NSString * const EMBSnapImportKey;
@property (strong, nonatomic) EMBImport *import;

extern NSString * const EMBSnapThumbnailPathKey;
@property (copy, nonatomic) NSString *thumbnailPath;

extern NSString * const EMBSnapDocumentPathKey;
@property (copy, nonatomic) NSString *documentPath;

extern NSString * const EMBSnapImageDimensionsKey;
@property (assign, nonatomic) CGSize imageDimensions;

extern NSString * const EMBSnapBookmarkKey;
@property (assign, getter = isBookmark, nonatomic) BOOL bookmark;

extern NSString * const EMBSnapMediaFileExtensionKey;
@property (copy, nonatomic) NSString *mediaFileExtension;

extern NSString * const EMBSnapColourAnalysedKey;
@property (assign, nonatomic) BOOL colourAnalysed;

extern NSString * const EMBSnapColourRedComponentKey;
@property (assign, nonatomic) NSNumber *colourRedComponent;

extern NSString * const EMBSnapColourGreenComponentKey;
@property (assign, nonatomic) NSNumber *colourGreenComponent;

extern NSString * const EMBSnapColourBlueComponentKey;
@property (assign, nonatomic) NSNumber *colourBlueComponent;

extern NSString * const EMBSnapSortColourValueKey;
@property (strong, nonatomic) NSNumber *sortColourValue;  // lower 24 bits only (HSB)

extern NSString * const EMBSnapScheduledForDeletionKey;
@property (assign, getter = isScheduledForDeletion, nonatomic) BOOL scheduledForDeletion;

extern NSString * const EMBSnapImportDateKey;
@property (readonly, strong, nonatomic) NSDate *importDate;

extern NSString * const EMBSnapExportFilenameKey;
@property (readonly, copy, nonatomic) NSString *exportFilename;

- (void)setSnapMetadata:(NSDictionary *)snapMetadata persistentStore:(NSPersistentStore *)persistentStore;

- (void)updateFromSnapDocument:(EMBSnapDocument *)snapDocument managedObjectContext:(NSManagedObjectContext *)managedObjectContext persistentStore:(NSPersistentStore *)persistentStore;

@end

@interface EMBSnap (CoreDataGeneratedAccessors)

- (void)addCollectionsObject:(EMBCollection *)collection;
- (void)removeCollectionsObject:(EMBCollection *)collection;
- (void)addCollections:(NSSet *)collections;
- (void)removeCollections:(NSSet *)collections;

- (void)addTagsObject:(EMBTag *)tag;
- (void)removeTagsObject:(EMBTag *)tag;
- (void)addTags:(NSSet *)tags;
- (void)removeTags:(NSSet *)tags;

@end
