//
//  RMRegistrationController.h
//  RMRegistrationKit
//
//  Created by Damien DeVille on 2/13/14.
//  Copyright (c) 2014 Realmac Software. All rights reserved.
//

#import <Cocoa/Cocoa.h>

extern NSString * const RMRegistrationApplicationVersionIdentifier;

@interface RMRegistrationController : NSObject

/*!
	\brief
	Present the registration window, application modally
	
	\param license
	The license to populate the license field with. Optional
	
	\param daysToExpiration
	The number of days left in the demo period. Pass `NSNotFound` if not appropriate. Optional
 */
- (void)showApplicationModalRegistrationWindow:(NSString *)license daysToExpiration:(NSInteger)daysToExpiration;

/*!
	\brief
	Stop the modal session on the application and hide the registration window
 */
- (void)hideApplicationModalRegistrationWindow;

/*!
	\brief
	The URL to the direct sale store for the application. Required
 */
@property (copy, nonatomic) NSURL *directStoreURL;

/*!
	\brief
	The URL to the mac app store for the application. Required
 */
@property (copy, nonatomic) NSURL *macAppStoreURL;

@end

@interface RMRegistrationController (Customization)

/*!
	\brief
	The text displayed as title in the header
 */
@property (copy, nonatomic) NSAttributedString *headerTitleText;

/*!
	\brief
	The text displayed as message in the header
 */
@property (copy, nonatomic) NSAttributedString *headerMessageText;

/*!
	\brief
	The background of the header
 */
@property (strong, nonatomic) NSColor *headerBackgroundColor;

@end

@interface RMRegistrationController (Verification)

/*!
	\brief
	Load and return the current license for the application
 */
- (NSString *)loadLicense;

/*!
	\brief
	Persist the license for the current application. Note that a notification with the license will be posted so that parts of the application can react to it
 */
- (void)saveLicense:(NSString *)license;

/*!
	\brief
	Verify a license for the current application
 */
+ (BOOL)verifyLicense:(NSString *)license error:(NSError **)errorRef;

@end

extern NSString * const RMRegistrationControllerLicenseVerifiedNotification;
	extern NSString * const RMRegistrationControllerLicenseKey;
